==> hydrogen_0.8.2.orig.tar.gz: hydrogen-0.8.2/hydrogen_gui/PatternEditor.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PatternEditor.h,v 1.36 2004/02/10 11:07:30 comix Exp $
 *
 */


#ifndef PATTERN_EDITOR_H
#define PATTERN_EDITOR_H

#include "qwidget.h"
#include "qtimer.h"
#include "qpixmap.h"
#include "qpainter.h"
#include "qapplication.h"
#include "qpopupmenu.h"


#include "lib/EngineListener.h"
#include "lib/Object.h"

#include "Globals.h"
#include "config.h"
#include "HydrogenApp.h"
#include "PatternEditorPanel.h"

class PatternEditorInstrumentList;
class PatternEditorVelocityRuler;
class PatternEditorPanel;

/**
 * Pattern editor
 */
class PatternEditor : public QWidget, public EngineListener, public Object {
	Q_OBJECT

	public:
		PatternEditor(QWidget* parent, PatternEditorPanel *pPanel);
		~PatternEditor();

		void mousePressEvent(QMouseEvent *ev);
		void paintEvent(QPaintEvent *ev);
		void setResolution(uint res, bool bUseTriplets);
		uint getResolution() {	return m_nResolution;	}
		bool isUsingTriplets() {	return m_bUseTriplets;	}

		void showEvent ( QShowEvent *ev );
		void hideEvent ( QHideEvent *ev );

		void setPatternEditorInstrumentList( PatternEditorInstrumentList* editor ) {	m_pPatternEditorInstrumentList = editor;	}
		void setPatternEditorVelocityRuler( PatternEditorVelocityRuler* pVelocityRuler ) {	m_pVelocityRuler = pVelocityRuler;	}

	public slots:
		void updateEditor(bool forceRepaint = false);

	private:
		uint m_nEditorWidth;
		uint m_nEditorHeight;

		uint m_nGridWidth;
		uint m_nGridHeight;

		QPixmap background;

		bool changed;
		bool notesChanged;

		uint m_nResolution;
		bool m_bUseTriplets;

		Pattern *currentPattern;
		
		PatternEditorPanel *m_pPatternEditorPanel;
		PatternEditorInstrumentList *m_pPatternEditorInstrumentList;
		PatternEditorVelocityRuler *m_pVelocityRuler;

		void drawNote(Note* note, uint nSequence, QPixmap *pixmap);
		void drawPattern(QPixmap *pixmap);
		void createBackground(QPixmap *pixmap);

		virtual void patternChanged();
		void customEvent( QCustomEvent *ev );

};





/**
 *
 */
class PatternEditorRuler : public QWidget, public Object
{
	Q_OBJECT

	public:
		PatternEditorRuler(QWidget* parent);
		~PatternEditorRuler();

		void paintEvent(QPaintEvent *ev);
		void updateStart(bool start);

		void showEvent ( QShowEvent *ev );
		void hideEvent ( QHideEvent *ev );

	public slots:
		void updateEditor( bool bRedrawAll = false );

	private:
		uint m_nRulerWidth;
		uint m_nRulerHeight;
		uint m_nGridWidth;
		QPixmap background;
		QPixmap tickPosition;
		QPixmap temp;
		QTimer *timer;
		uint nTicks;
		bool changed;
};



/**
 *
 */
class PatternEditorInstrumentList : public QWidget, public EngineListener, public Object {
	Q_OBJECT

	public:
		PatternEditorInstrumentList( QWidget *parent, PatternEditor *pPatternEditor, PatternEditorPanel *pPanel );
		~PatternEditorInstrumentList();


	public slots:
		void updateEditor();

		void functionClearNotes();
		void functionFillNotes();
		void functionProperties();
		void functionMute();
		void functionSolo();
		void functionLoad();


	private:
		PatternEditorPanel *m_pPatternEditorPanel;
		PatternEditor *m_pPatternEditor;
		uint m_nGridHeight;
		uint m_nEditorWidth;
		uint m_nEditorHeight;
		bool changed;
		QPixmap background;
		QPixmap temp;

		QPixmap genericIcon;
		QPopupMenu *functionPopup;


		virtual void patternChanged();
		void customEvent( QCustomEvent *ev );
		void paintEvent(QPaintEvent *ev);
		void createBackground(QPixmap *pixmap);
		void mousePressEvent(QMouseEvent *ev);
};



/**
 *
 */
class PatternEditorVelocityRuler : public QWidget, public EngineListener, public Object
{
	Q_OBJECT

	public:
		PatternEditorVelocityRuler( QWidget *parent, PatternEditor *pPatternEditor, PatternEditorPanel *pPanel );
		~PatternEditorVelocityRuler();


	public slots:
		void updateEditor();


	private:
		PatternEditorPanel *m_pPatternEditorPanel;
		Pattern *m_pCurrentPattern;
		PatternEditor *m_pPatternEditor;
		uint m_nGridWidth;
		uint m_nEditorWidth;
		uint m_nEditorHeight;

		bool m_bChanged;
		QPixmap m_background;

		virtual void patternChanged();

		void customEvent( QCustomEvent *ev );
		void createBackground(QPixmap *pixmap);
		void paintEvent(QPaintEvent *ev);
		void mousePressEvent(QMouseEvent *ev);
		void mouseMoveEvent(QMouseEvent *ev);

};

#endif

==> hydrogen_0.9.1.orig.tar.gz: hydrogen-0.9.1/hydrogen_gui/PatternEditor.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2004 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://hydrogen.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: PatternEditor.h,v 1.44 2004/07/19 09:20:11 comix Exp $
 *
 */


#ifndef PATTERN_EDITOR_H
#define PATTERN_EDITOR_H

#include "qwidget.h"
#include "qtimer.h"
#include "qpixmap.h"
#include "qpainter.h"
#include "qapplication.h"
#include "qpopupmenu.h"


#include "lib/EngineListener.h"
#include "lib/Object.h"

class PatternEditorInstrumentList;
class PatternEditorVelocityRuler;
class PatternEditorPanel;

///
/// Pattern editor
///
class PatternEditor : public QWidget, public Object {
	Q_OBJECT

	public:
		PatternEditor(QWidget* parent, PatternEditorPanel *pPatternEditorPanel);
		~PatternEditor();

		void paintEvent(QPaintEvent *ev);
		void setResolution(uint res, bool bUseTriplets);
		uint getResolution() {	return m_nResolution;	}
		bool isUsingTriplets() {	return m_bUseTriplets;	}

		void showEvent ( QShowEvent *ev );
		void hideEvent ( QHideEvent *ev );

	public slots:
		void updateEditor(bool forceRepaint = false);

	private:
		uint m_nEditorWidth;
		uint m_nEditorHeight;
		uint m_nGridWidth;
		uint m_nGridHeight;

		QPixmap m_background;

		bool m_bChanged;
		bool m_bNotesChanged;

		uint m_nResolution;
		bool m_bUseTriplets;

		// usati per la lunghezza della nota
		bool m_bRightBtnPressed;
		Note *m_pDraggedNote;
		//~
		
		Pattern *m_pPattern;

		PatternEditorPanel *m_pPatternEditorPanel;

		void drawNote(Note* note, uint nSequence, QPixmap *pixmap);
		void drawPattern(QPixmap *pixmap);
		void createBackground(QPixmap *pixmap);

		void mousePressEvent(QMouseEvent *ev);
		void mouseReleaseEvent(QMouseEvent *ev);
		void mouseMoveEvent(QMouseEvent *ev);
		void keyPressEvent (QKeyEvent *ev);

		int getColumn(QMouseEvent *ev);

		// selecting/moving/copying notes etc
		enum RegionManipulationMode {
			COPY,
			MOVE,
			DELETE
		};

		bool m_bLasso;
		bool m_bLassoRepaint;
		bool m_bDrag;
		bool m_bDragRepaint;
		bool m_bSelect;
		bool m_bDragCopy;
		QPoint m_mousePos;
		QRect m_srcRegion;
		QRect m_oldRegion;
		QRect m_dstRegion;
		bool inSelect( int nColumn, int nRow, QRect area);
		uint getXPos(int nColumn);
		uint getYPos(int nRow);
		int getSnapWidth();
		void markupNotes();
		void copyNotes();
		void manipulateRegion(RegionManipulationMode mode);
		vector <Note*> m_noteList;
		vector <QPoint> m_notePoint;
};





class PatternEditorRuler : public QWidget, public Object
{
	Q_OBJECT

	public:
		PatternEditorRuler(QWidget* parent, PatternEditorPanel *pPatternEditorPanel);
		~PatternEditorRuler();

		void paintEvent(QPaintEvent *ev);
		void updateStart(bool start);

		void showEvent ( QShowEvent *ev );
		void hideEvent ( QHideEvent *ev );

	public slots:
		void updateEditor( bool bRedrawAll = false );

	private:
		uint m_nRulerWidth;
		uint m_nRulerHeight;
		uint m_nGridWidth;
		QPixmap m_background;
		QPixmap m_tickPosition;
		QPixmap m_temp;
		QTimer *m_pTimer;
		int m_nTicks;
		bool m_bChanged;
		PatternEditorPanel *m_pPatternEditorPanel;
		Pattern *m_pPattern;

};



class PatternEditorInstrumentList : public QWidget, public Object {
	Q_OBJECT

	public:
		PatternEditorInstrumentList( QWidget *parent, PatternEditorPanel *pPatternEditorPanel );
		~PatternEditorInstrumentList();


	public slots:
		void updateEditor();

		void functionClearNotes();
		void functionFillNotes();
		void functionMute();
		void functionSolo();
		//void functionLoad();


	private:
		PatternEditorPanel *m_pPatternEditorPanel;
		Pattern *m_pPattern;
		uint m_nGridHeight;
		uint m_nEditorWidth;
		uint m_nEditorHeight;
		bool m_bChanged;
		QPixmap m_background;
		QPixmap m_temp;

		QPixmap m_genericIcon;
		QPopupMenu *m_pFunctionPopup;

		void paintEvent(QPaintEvent *ev);
		void createBackground(QPixmap *pixmap);
		void mousePressEvent(QMouseEvent *ev);
		Pattern* getCurrentPattern();
};



class NotePropertiesRuler : public QWidget, public Object
{
	Q_OBJECT

	public:
		enum NotePropertiesMode {
			VELOCITY,
			PITCH
		};
	
		NotePropertiesRuler( QWidget *parent, PatternEditorPanel *pPatternEditorPanel );
		~NotePropertiesRuler();

		void setMode( NotePropertiesMode mode );
		NotePropertiesMode getMode() {	return m_mode;	}
		
	public slots:
		void updateEditor();

	private:
		NotePropertiesMode m_mode;
	
		PatternEditorPanel *m_pPatternEditorPanel;
		Pattern *m_pPattern;
		uint m_nGridWidth;
		uint m_nEditorWidth;
		uint m_nEditorHeight;

		bool m_bChanged;
		QPixmap m_background;

		void createBackground(QPixmap *pixmap);
		void paintEvent(QPaintEvent *ev);
		void mousePressEvent(QMouseEvent *ev);
		void mouseMoveEvent(QMouseEvent *ev);

};

#endif
